@@ -1,7 +1,8 @@
-import sys
 import convertible
 import inspect
-import traceback
+import logger
+
+log = logger.get_logger('app')
 
 
 def call(func, kwargs):
@@ -31,11 +32,7 @@ def run(runner, debug=False, text=False):
         else:
             respond(data)
     except Exception, e:
-        if debug:
-            print '-'*60
-            traceback.print_exc(file=sys.stdout)
-            print '-'*60
-
+        log.exception('got an exception')
         respond(e, str(e), success=False)
         exit(1)
 
